@@ -6,7 +6,16 @@ use 5.008001;
 use parent 'Alien::Base';
 
 # ABSTRACT: Build and make available bz2
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
+
+
+sub alien_helper
+{
+  return {
+    bzip2 => sub { 'bzip2' },
+  };
+}
+
 
 
 1;
@@ -23,7 +32,7 @@ Alien::Libbz2 - Build and make available bz2
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -51,6 +60,14 @@ Returns the C compiler flags.
 
 Returns the linker flags.
 
+=head1 HELPERS
+
+=head2 bzip2
+
+ %{bzip2}
+
+Returns the name of the bzip2 command.  Usually just C<bzip2>.
+
 =head1 SEE ALSO
 
 =over 4
@@ -73,7 +90,7 @@ Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
